@@ -58,6 +58,7 @@ class BaseData:
         * SUCCESS     When backend responds with status "SUCCESS"
                       and prospect date is lower or equal than max_days_old
         * NO_DATA     When Datasource responds 200, but no Data was returned
+        * INCOMPLETE  When Datasource responds 200, but Data prospected is incomplete
         * EXPIRED     When backend responds with status "SUCCESS"
                       and prospect date is greater than max_days_old
         * ERROR       When backend responds a integration error
@@ -68,7 +69,7 @@ class BaseData:
         :param max_days_old: Max days old for current data, for check expiration.
         :param max_periods_old: Max months old for current data, for check expiration.
         """
-        if self.integration_status == "SUCCESS":
+        if self.integration_status in ["SUCCESS", "INCOMPLETE", "NO_DATA"]:
             days_old = (
                 arrow.utcnow().ceil("day") - arrow.get(self.prospect_date).floor("day")
             ).days
@@ -78,7 +79,9 @@ class BaseData:
                 max_periods_old is not None and months_old > max_periods_old
             )
             self.integration_status = (
-                "EXPIRED" if expired_by_date or expired_by_period else "SUCCESS"
+                "EXPIRED"
+                if expired_by_date or expired_by_period
+                else self.integration_status
             )
             if expired_by_period or expired_by_period:
                 self.integration_status = "EXPIRED"
