@@ -7,9 +7,10 @@ from dotenv import load_dotenv
 from loguru import logger
 from scalpl import Cut
 
+from snatch.helpers.merge_dicts import merge_dicts
 from snatch.helpers.secrets_manager import SecretManager
 
-load_dotenv()
+load_dotenv(verbose=True)
 
 
 def get_environment_from_secrets_manager(
@@ -56,55 +57,56 @@ def get_environment_from_secrets_manager(
     return secrets_manager_data
 
 
+def get_datasource_url(name: str) -> str:
+    env_name = f"SNATCH_{name.upper()}_URL"
+    url = os.getenv(env_name)
+    if url:
+        logger.debug(f"Using value from {env_name}")
+        return url
+    return f"http://{name}"
+
+
 def get_settings(environment: Optional[str], log_level: str):
 
     config = {
         "snatch": {
             "boa_vista_secret_token": os.getenv("SNATCH_BOA_VISTA_SECRET_TOKEN", "foo"),
-            "datasource_boa_vista_url": os.getenv(
-                "SNATCH_DATASOURCE_BOA_VISTA_URL", "http://datasource_boa_vista"
-            ),
+            "datasource_boa_vista_url": get_datasource_url("datasource_boa_vista"),
             "banco_central_secret_token": os.getenv(
                 "SNATCH_BANCO_CENTRAL_SECRET_TOKEN", "foo"
             ),
-            "datasource_banco_central_url": os.getenv(
-                "SNATCH_DATASOURCE_BANCO_CENTRAL_URL", "http://datasource_banco_central"
+            "datasource_banco_central_url": get_datasource_url(
+                "datasource_banco_central"
             ),
             "qsa_secret_token": os.getenv("SNATCH_QSA_SECRET_TOKEN", "foo"),
-            "datasource_qsa_url": os.getenv(
-                "SNATCH_DATASOURCE_QSA_URL", "http://datasource_qsa"
-            ),
+            "datasource_qsa_url": get_datasource_url("datasource_qsa"),
             "pep_secret_token": os.getenv("SNATCH_PEP_SECRET_TOKEN", "foo"),
-            "datasource_pep_url": os.getenv(
-                "SNATCH_DATASOURCE_PEP_URL", "http://datasource_pep"
-            ),
+            "datasource_pep_url": get_datasource_url("datasource_pep"),
             "rf_secret_token": os.getenv("SNATCH_RF_SECRET_TOKEN", "foo"),
-            "datasource_rf_url": os.getenv(
-                "SNATCH_DATASOURCE_RF_URL", "http://datasource_rf"
-            ),
+            "datasource_rf_url": get_datasource_url("datasource_rf"),
             "ibama_secret_token": os.getenv("SNATCH_IBAMA_SECRET_TOKEN", "foo"),
-            "datasource_ibama_url": os.getenv(
-                "SNATCH_DATASOURCE_IBAMA_URL", "http://datasource_ibama"
-            ),
+            "datasource_ibama_url": get_datasource_url("datasource_ibama"),
             "data_risk_secret_token": os.getenv("SNATCH_DATA_RISK_SECRET_TOKEN", "foo"),
-            "datasource_data_risk_url": os.getenv(
-                "SNATCH_DATASOURCE_DATA_RISK_URL", "http://datasource_data_risk"
-            ),
+            "datasource_data_risk_url": get_datasource_url("datasource_data_risk"),
             "fgts_secret_token": os.getenv("SNATCH_FGTS_SECRET_TOKEN", "foo"),
-            "datasource_fgts_url": os.getenv(
-                "SNATCH_DATASOURCE_FGTS_URL", "http://datasource_fgts"
-            ),
+            "datasource_fgts_url": get_datasource_url("datasource_fgts"),
             "protest_secret_token": os.getenv("SNATCH_PROTEST_SECRET_TOKEN", "foo"),
-            "datasource_protest_url": os.getenv(
-                "SNATCH_DATASOURCE_PROTEST_URL", "http://datasource_data_risk"
-            ),
+            "datasource_protest_url": get_datasource_url("datasource_protest"),
+            "pgfn_secret_token": os.getenv("SNATCH_PGFN_SECRET_TOKEN", "foo"),
+            "datasource_pgfn_url": get_datasource_url("datasource_pgfn"),
+            "tst_secret_token": os.getenv("SNATCH_TST_SECRET_TOKEN", "foo"),
+            "datasource_tst_url": get_datasource_url("datasource_tst"),
+            "ceis_secret_token": os.getenv("SNATCH_CEIS_SECRET_TOKEN", "foo"),
+            "datasource_ceis_url": get_datasource_url("datasource_ceis"),
+            "cnep_secret_token": os.getenv("SNATCH_CNEP_SECRET_TOKEN", "foo"),
+            "datasource_cnep_url": get_datasource_url("datasource_cnep"),
         }
     }
-    config.update(
-        get_environment_from_secrets_manager(
-            environment=environment, log_level=log_level
-        )
+    data_from_secrets = get_environment_from_secrets_manager(
+        environment=environment, log_level=log_level
     )
 
+    merge_dicts(source_dict=data_from_secrets, target_dict=config)
+
     settings = Cut(config)
     return settings
